@@ -24,12 +24,11 @@ class Box(object):
     Box 打包解包
     """
 
-    # 只能继承时修改
+    # 继承时可修改
     header_attrs = HEADER_ATTRS
-    # 只能继承时修改. 网络字节序
+    # 网络字节序. 继承时可修改
     header_fmt_type = '!'
 
-    header_keys = None
     header_fmt = None
     header_len = None
 
@@ -39,13 +38,8 @@ class Box(object):
     body = None
 
     def __init__(self, init_data=None):
-        # 为了优化性能，不用每次都计算
-        # 验证过，继承后，这里的__class__是子类类型，所以可以放心继承
-        cls = self.__class__
-        if cls.header_keys is None or cls.header_fmt is None or cls.header_len is None:
-            cls.header_keys = cls.header_attrs.keys()
-            cls.header_fmt = cls.header_fmt_type + ''.join(value[0] for value in cls.header_attrs.values())
-            cls.header_len = struct.calcsize(cls.header_fmt)
+        self.header_fmt = self.header_fmt_type + ''.join(value[0] for value in self.header_attrs.values())
+        self.header_len = struct.calcsize(self.header_fmt)
 
         self.reset()
         if init_data and isinstance(init_data, dict):
@@ -82,7 +76,7 @@ class Box(object):
         """
         打包
         """
-        values = [getattr(self, k) for k in self.header_keys]
+        values = [getattr(self, k) for k in self.header_attrs]
 
         return struct.pack(self.header_fmt, *values) + self.body
 
@@ -98,10 +92,7 @@ class Box(object):
             0: 继续收
         """
 
-        # len(buf) 改为 buf_len 之后，性能居然提升了不少
-        buf_len = len(buf)
-
-        if buf_len < self.header_len:
+        if len(buf) < self.header_len:
             # logger.error('buf.len(%s) should > header_len(%s)' % (len(buf), self.header_len))
             # raise ValueError('buf.len(%s) should > header_len(%s)' % (len(buf), HEADER_LEN))
             return 0
@@ -112,7 +103,7 @@ class Box(object):
             logger.error('unpack fail.', exc_info=True)
             return -1
 
-        dict_values = dict([(key, values[i]) for i, key in enumerate(self.header_keys)])
+        dict_values = dict([(key, values[i]) for i, key in enumerate(self.header_attrs.keys())])
 
         if hasattr(self, 'magic'):
             magic = dict_values.get('magic')
@@ -129,7 +120,7 @@ class Box(object):
             logger.error('there is no packet_len or body_len in header')
             return -3
 
-        if buf_len < packet_len:
+        if len(buf) < packet_len:
             # 还要继续收
             return 0
 
@@ -195,7 +186,7 @@ class Box(object):
         self.body = json.dumps(value)
 
     def __repr__(self):
-        values = [(k, getattr(self, k)) for k in self.header_keys]
+        values = [(k, getattr(self, k)) for k in self.header_attrs]
 
         values.append(('body', self.body))
 
